@@ -1,4 +1,4 @@
-from .servicex import ServiceXDataset  # NOQA
+from .servicex import ServiceXDataset, StreamInfoUrl, StreamInfoPath  # NOQA
 from .utils import (  # NOQA
     ServiceXException,
     ServiceXUnknownRequestID,
@@ -6,8 +6,10 @@ from .utils import (  # NOQA
     ServiceXFatalTransformException,
     StatusUpdateCallback,
     StatusUpdateFactory,
+    ServiceXUnknownDataRequestID,
     clean_linq,
+    DatasetType,
 )
 from .servicex_adaptor import ServiceXAdaptor  # NOQA
 from .minio_adaptor import MinioAdaptor  # NOQA
-from .cache import Cache, ignore_cache  # NOQA
+from .cache import Cache, ignore_cache, update_local_query_cache  # NOQA
